API Reference
=============

REST Client
-----------

.. autoclass:: fuelog.FuelogClient
   :members:
   :show-inheritance:

MCP Client
----------

.. autoclass:: fuelog.FuelogMCPClient
   :members:
   :show-inheritance:

Models
------

Fuel Logs
~~~~~~~~~

.. autoclass:: fuelog.FuelLog
   :members:

.. autoclass:: fuelog.CreateFuelLogRequest
   :members:

.. autoclass:: fuelog.UpdateFuelLogRequest
   :members:

Vehicles
~~~~~~~~

.. autoclass:: fuelog.Vehicle
   :members:

.. autoclass:: fuelog.CreateVehicleRequest
   :members:

.. autoclass:: fuelog.UpdateVehicleRequest
   :members:

Analytics
~~~~~~~~~

.. autoclass:: fuelog.AnalyticsStats
   :members:

MCP Results
~~~~~~~~~~~

.. autoclass:: fuelog.MCPToolResult
   :members:

.. autoclass:: fuelog.MCPPromptResult
   :members:

.. autoclass:: fuelog.MCPPromptMessage
   :members:

Enumerations
------------

.. autoclass:: fuelog.FuelType
   :members:
   :undoc-members:

.. autoclass:: fuelog.TrendMetric
   :members:
   :undoc-members:

.. autoclass:: fuelog.CostOptimizationPeriod
   :members:
   :undoc-members:
